# *********************************************************************
# This Original Work is copyright of 51 Degrees Mobile Experts Limited.
# Copyright 2019 51 Degrees Mobile Experts Limited, 5 Charlotte Close,
# Caversham, Reading, Berkshire, United Kingdom RG4 7BY.
#
# This Original Work is licensed under the European Union Public Licence (EUPL) 
# v.1.2 and is subject to its terms as set out below.
#
# If a copy of the EUPL was not distributed with this file, You can obtain
# one at https://opensource.org/licenses/EUPL-1.2.
#
# The 'Compatible Licences' set out in the Appendix to the EUPL (as may be
# amended by the European Commission) shall be deemed incompatible for
# the purposes of the Work and the provisions of the compatibility
# clause in Article 5 of the EUPL shall not apply.
# 
# If using the Work as, or as part of, a network application, by 
# including the attribution notice(s) required under Article 5 of the EUPL
# in the end user terms of the application under an appropriate heading, 
# such notice(s) shall fulfill the requirements of that article.
# ********************************************************************

from fiftyone_pipeline_cloudrequestengine.cloudengine import CloudEngine

class LocationCloud(CloudEngine):
    """!
    The location cloud engine requires the 51Degrees
    cloudRequestEngine to be placed in a pipeline before it.
    It takes that raw JSON response and parses it to extract the
    location part. It also uses this data to generate a list of properties
    """
    def __init__(self, location_provider="fiftyonedegrees"):
        """!
        Constructor for location engine
        @type location_provider: string
        @param location_provider: fiftyonedegrees or digitalelement
        """

        super(LocationCloud, self).__init__()

        if location_provider == "fiftyonedegrees":
            self.datakey = "location"
        elif location_provider == "digitalelement":
            self.datakey = "location_digitalelement"
        else:
            raise Exception("The location provider " + location_provider + " was not recognized.")



# *********************************************************************
# This Original Work is copyright of 51 Degrees Mobile Experts Limited.
# Copyright 2019 51 Degrees Mobile Experts Limited, 5 Charlotte Close,
# Caversham, Reading, Berkshire, United Kingdom RG4 7BY.
#
# This Original Work is licensed under the European Union Public Licence (EUPL) 
# v.1.2 and is subject to its terms as set out below.
#
# If a copy of the EUPL was not distributed with this file, You can obtain
# one at https://opensource.org/licenses/EUPL-1.2.
#
# The 'Compatible Licences' set out in the Appendix to the EUPL (as may be
# amended by the European Commission) shall be deemed incompatible for
# the purposes of the Work and the provisions of the compatibility
# clause in Article 5 of the EUPL shall not apply.
# 
# If using the Work as, or as part of, a network application, by 
# including the attribution notice(s) required under Article 5 of the EUPL
# in the end user terms of the application under an appropriate heading, 
# such notice(s) shall fulfill the requirements of that article.
# ********************************************************************

from fiftyone_pipeline_core.pipelinebuilder import PipelineBuilder
from fiftyone_pipeline_cloudrequestengine.cloudrequestengine import CloudRequestEngine
from .location_cloud import LocationCloud

class LocationPipelineBuilder(PipelineBuilder):
    """!
    The Location Pipeline Builder allows you to easily
    Construct a pipeline containing the location cloud engine
    
     Internal function for getting evidence keys used by cloud engines
     
      @type resource_key: string
      @param resource_key: The 51Degrees cloud service resource key
      @type location_provider: string
      @param location_provider: fiftyonedegrees or digitalelement
      @type settings: dict
      @param settings: Settings for the pipeline. 
      Can contain a `cloud_endpoint` url
      if overriding the default one. An optional cache can be added by passing an instance of 
      the DataKeyedCache class as a `cache` setting 
      The pipeline builder can also contain javascript_builder_settings settings
      see the documentation for the base PipelineBuilder and JavaScriptBuilder class 
      
    """
    def __init__(self, resource_key, location_provider="fiftyonedegrees", settings={}):

        super(LocationPipelineBuilder, self).__init__(settings)

        # Add specific engines

        settings["resource_key"] = resource_key

        self.add(CloudRequestEngine(settings))

        location = LocationCloud(location_provider=location_provider)

        if "cache" in settings:
            location.set_cache(settings["cache"])
        
        self.add(location)




import setuptools
from version import __VERSION__

# read the contents of your README file
from os import path
this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'readme.md'), encoding='utf-8') as f:
    long_description = f.read()

# Get the package version from GitVersion Tag
gitversion = __VERSION__
package_version = gitversion.split("+")[0]

setuptools.setup(
    name="fiftyone_location",
	version=package_version,
    author="51Degrees",
    author_email="support@51degrees.com",
    url="https://51degrees.com/",
    description=("The 51Degrees Pipeline API is a generic web request intelligence and data processing solution with the ability to add a range of 51Degrees and/or custom plug ins (Engines). "
    "This repository contains the geo-location engines for the Python implementation of the Pipeline API."),
    long_description=long_description,
    long_description_content_type='text/markdown',
    python_requires='>=3.5',
    packages=["fiftyone_location"],
    install_requires=["fiftyone_pipeline_core", "fiftyone_pipeline_engines", "fiftyone_pipeline_cloudrequestengine", "gitversion"],
    license="EUPL-1.2",
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Programming Language :: Python",
        "License :: OSI Approved :: European Union Public Licence 1.2 (EUPL 1.2)",
        "Operating System :: OS Independent",
        "Topic :: Software Development :: Libraries :: Python Modules"
    ],
    include_package_data=True
)
